@@ -8,3 +8,12 @@ from lusid_notifications.api.manual_event_api import ManualEventApi
 from lusid_notifications.api.notifications_api import NotificationsApi
 from lusid_notifications.api.subscriptions_api import SubscriptionsApi
 
+
+__all__ = [
+    "ApplicationMetadataApi",
+    "DeliveriesApi",
+    "EventTypesApi",
+    "ManualEventApi",
+    "NotificationsApi",
+    "SubscriptionsApi"
+]
